{-# LANGUAGE OverloadedStrings #-}

module Level.Joyce where

import qualified Data.Text.Lazy as T
import System.Random
import Data.Char

import Types
import Rand
import Level.Random

level :: Rand -> Int -> Level
level r minheight = map trim $ reverse $ formatLevel reverse minheight $
	addFeatures (zip stream (featureStream r))
  where
	stream = withStdGen r (reversedOriginal ulysses)
		(infiniteStreamOfReverseConciousness ulysses)
	trim = reverse . dropWhile isSpace . reverse

data Joyce = Ulysses
	{ chunksOfConciousness :: [T.Text]
	, conclusion :: T.Text
	, connectingWord :: T.Text -- typically " and "
	}

reversedOriginal :: Joyce -> [String]
reversedOriginal j = reverse $ words $ T.unpack $ 
	T.intercalate (connectingWord j) (chunksOfConciousness j)
		`T.append` conclusion j

infiniteStreamOfReverseConciousness :: Joyce -> StdGen -> [String]
infiniteStreamOfReverseConciousness j r = end ++ concat (stream r)
  where
	stream g = 
		let (n, g') = randomR range g
		in reverse (connector : words (chunks !! n)) : stream g'
	range = (0, length (chunksOfConciousness j) - 1)
	chunks = map T.unpack (chunksOfConciousness j)
	connector = filter (/= ' ') (T.unpack (connectingWord j)) ++ ","
	end = reverse (connector : words (T.unpack (conclusion j)))

ulysses :: Joyce
ulysses = Ulysses
	{ chunksOfConciousness = T.splitOn (connectingWord ulysses) partoflastsentence
	, conclusion = " his heart was going like mad and yes I said yes I will Yes."
	, connectingWord = " and "
	}
  where
	partoflastsentence :: T.Text
	-- longest line of code that will ever appear in a program I write
	partoflastsentence = "that was a relief wherever you be let your wind go free who knows if that pork chop I took with my cup of tea after was quite good with the heat I couldn't smell anything off it I'm sure that queerlooking man in the porkbutchers is a great rogue I hope that lamp is not smoking fill my nose up with smuts better than having him leaving the gas on all night I couldn't rest easy in my bed in Gibraltar even getting up to see why am I so damned nervous about that though I like it in the winter its more company O Lord it was rotten cold too that winter when I was only about ten was I yes I had the big doll with all the funny clothes dressing her up and undressing that icy wind skeeting across from those mountains the something Nevada sierra nevada standing at the fire with the little bit of a short shift I had up to heat myself I loved dancing about in it then make a race back into bed I'm sure that fellow opposite used to be there the whole time watching with the lights out in the summer and I in my skin hopping around I used to love myself then stripped at the washstand dabbing and creaming only when it came to the chamber performance I put out the light too so then there were 2 of us goodbye to my sleep for this night anyhow I hope he's not going to get in with those medicals leading him astray to imagine he's young again coming in at 4 in the morning it must be if not more still he had the manners not to wake me what do they find to gabber about all night squandering money and getting drunker and drunker couldn't they drink water then he starts giving us his orders for eggs and tea and Findon haddy and hot buttered toast I suppose well have him sitting up like the king of the country pumping the wrong end of the spoon up and down in his egg wherever he learned that from and I love to hear him falling up the stairs of a morning with the cups rattling on the tray and then play with the cat she rubs up against you for her own sake I wonder has she fleas shes as bad as a woman always licking and lecking but I hate their claws I wonder do they see anything that we cant staring like that when she sits at the top of the stairs so long and listening as I wait always what a robber too that lovely fresh place I bought I think I'll get a bit of fish tomorrow or today is it Friday yes I will with some blancmange with black currant jam like long ago not those 2 lb pots of mixed plum and apple from the London and Newcastle Williams and Woods goes twice as far only for the bones I hate those eels cod yes I'll get a nice piece of cod I'm always getting enough for 3 forgetting anyway I'm sick of that everlasting butchers meat from Buckleys loin chops and leg beef and rib steak and scrag of mutton and calfs pluck the very name is enough or a picnic suppose we all gave 5/- each and or let him pay it and invite some other woman for him who Mrs Fleming and drove out to the furry glen or the strawberry beds wed have him examining all the horses toenails first like he does with the letters no not with Boylan there yes with some cold veal and ham mixed sandwiches there are little houses down at the bottom of the banks there on purpose but its as hot as blazes he says not a bank holiday anyhow I hate those ruck of Mary Ann coalboxes out for the day Whit Monday is a cursed day too no wonder that bee bit him better the seaside but I'd never again in this life get into a boat with him after him at Bray telling the boatman he knew how to row if anyone asked could he ride the steeplechase for the gold cup he'd say yes then it came on to get rough the old thing crookeding about and the weight all down my side telling me pull the right reins now pull the left and the tide all swamping in floods in through the bottom and his oar slipping out of the stirrup its a mercy we werent all drowned he can swim of course me no there's no danger whatsoever keep yourself calm in his flannel trousers I'd like to have tattered them down off him before all the people and give him what that one calls flagellate till he was black and blue do him all the good in the world only for that longnosed chap I dont know who he is with that other beauty Burke out of the City Arms hotel was there spying around as usual on the slip always where he wasnt wanted if there was a row on you'd vomit a better face there was no love lost between us thats 1 consolation I wonder what kind is that book he brought me Sweets of Sin by a gentleman of fashion some other Mr de Kock I suppose the people gave him that nickname going about with his tube from one woman to another I couldn't even change my new white shoes all ruined with the saltwater and the hat I had with that feather all blowy and tossed on me how annoying and provoking because the smell of the sea excited me of course the sardines and the bream in Catalan bay round the back of the rock they were fine all silver in the fishermens baskets old Luigi near a hundred they said came from Genoa and the tall old chap with the earrings I dont like a man you have to climb up to to get at I suppose theyre all dead and rotten long ago besides I dont like being alone in this big barracks of a place at night I suppose I'll have to put up with it I never brought a bit of salt in even when we moved in the confusion musical academy he was going to make on the first floor drawingroom with a brassplate or Blooms private hotel he suggested go and ruin himself altogether the way his father did down in Ennis like all the things he told father he was going to do and me but I saw through him telling me all the lovely places we could go for the honeymoon Venice by moonlight with the gondolas and the lake of Como he had a picture cut out of some paper of and mandolines and lanterns O how nice I said whatever I liked he was going to do immediately if not sooner will you be my man will you carry my can he ought to get a leather medal with a putty rim for all the plans he invents then leaving us here all day you'd never know what old beggar at the door for a crust with his long story might be a tramp and put his foot in the way to prevent me shutting it like that picture of that hardened criminal he was called in Lloyds Weekly news 20 years in jail then he comes out and murders an old woman for her money imagine his poor wife or mother or whoever she is such a face you'd run miles away from I couldn't rest easy till I bolted all the doors and windows to make sure but its worse again being locked up like in a prison or a madhouse they ought to be all shot or the cat of nine tails a big brute like that that would attack a poor old woman to murder her in her bed I'd cut them off him so I would not that he'd be much use still better than nothing the night I was sure I heard burglars in the kitchen and he went down in his shirt with a candle and a poker as if he was looking for a mouse as white as a sheet frightened out of his wits making as much noise as he possibly could for the burglars benefit there isnt much to steal indeed the Lord knows still its the feeling especially now with Milly away such an idea for him to send the girl down there to learn to take photographs on account of his grandfather instead of sending her to Skerrys academy where shed have to learn not like me getting all IS at school only he'd do a thing like that all the same on account of me and Boylan thats why he did it I'm certain the way he plots and plans everything out I couldn't turn round with her in the place lately unless I bolted the door first gave me the fidgets coming in without knocking first when I put the chair against the door just as I was washing myself there below with the glove get on your nerves then doing the loglady all day put her in a glasscase with two at a time to look at her if he knew she broke off the hand off that little gimcrack statue with her roughness and carelessness before she left that I got that little Italian boy to mend so that you cant see the join for 2 shillings wouldnt even teem the potatoes for you of course shes right not to ruin her hands I noticed he was always talking to her lately at the table explaining things in the paper and she pretending to understand sly of course that comes from his side of the house he cant say I pretend things can he I'm too honest as a matter of fact and helping her into her coat but if there was anything wrong with her its me shed tell not him I suppose he thinks I'm finished out and laid on the shelf well I'm not no nor anything like it well see well see now shes well on for flirting too with Tom Devans two sons imitating me whistling with those romps of Murray girls calling for her can Milly come out please shes in great demand to pick what they can out of her round in Nelson street riding Harry Devans bicycle at night its as well he sent her where she is she was just getting out of bounds wanting to go on the skatingrink and smoking their cigarettes through their nose I smelt it off her dress when I was biting off the thread of the button I sewed on to the bottom of her jacket she couldn't hide much from me I tell you only I oughtnt to have stitched it and it on her it brings a parting and the last plumpudding too split in 2 halves see it comes out no matter what they say her tongue is a bit too long for my taste your blouse is open too low she says to me the pan calling the kettle blackbottom and I had to tell her not to cock her legs up like that on show on the windowsill before all the people passing they all look at her like me when I was her age of course any old rag looks well on you then a great touchmenot too in her own way at the Only Way in the Theatre royal take your foot away out of that I hate people touching me afraid of her life I'd crush her skirt with the pleats a lot of that touching must go on in theatres in the crush in the dark theyre always trying to wiggle up to you that fellow in the pit at the Gaiety for Beerbohm Tree in Trilby the last time I'll ever go there to be squashed like that for any Trilby or her barebum every two minutes tipping me there and looking away he's a bit daft I think I saw him after trying to get near two stylishdressed ladies outside Switzers window at the same little game I recognised him on the moment the face and everything but he didnt remember me yes and she didnt even want me to kiss her at the Broadstone going away well I hope shell get someone to dance attendance on her the way I did when she was down with the mumps and her glands swollen wheres this and wheres that of course she cant feel anything deep yet I never came properly till I was what 22 or so it went into the wrong place always only the usual girls nonsense and giggling that Conny Connolly writing to her in white ink on black paper sealed with sealingwax though she clapped when the curtain came down because he looked so handsome then we had Martin Harvey for breakfast dinner and supper I thought to myself afterwards it must be real love if a man gives up his life for her that way for nothing I suppose there are a few men like that left its hard to believe in it though unless it really happened to me the majority of them with not a particle of love in their natures to find two people like that nowadays full up of each other that would feel the same way as you do theyre usually a bit foolish in the head his father must have been a bit queer to go and poison himself after her still poor old man I suppose he felt lost shes always making love to my things too the few old rags I have wanting to put her hair up at I S my powder too only ruin her skin on her shes time enough for that all her life after of course shes restless knowing shes pretty with her lips so red a pity they wont stay that way I was too but there's no use going to the fair with the thing answering me like a fishwoman when I asked to go for a half a stone of potatoes the day we met Mrs Joe Gallaher at the trottingmatches and she pretended not to see us in her trap with Friery the solicitor we werent grand enough till I gave her 2 damn fine cracks across the ear for herself take that now for answering me like that and that for your impudence she had me that exasperated of course contradicting I was badtempered too because how was it there was a weed in the tea or I didnt sleep the night before cheese I ate was it and I told her over and over again not to leave knives crossed like that because she has nobody to command her as she said herself well if he doesnt correct her faith I will that was the last time she turned on the teartap I was just like that myself they darent order me about the place its his fault of course having the two of us slaving here instead of getting in a woman long ago am I ever going to have a proper servant again of course then shed see him coming I'd have to let her know or shed revenge it arent they a nuisance that old Mrs Fleming you have to be walking round after her putting the things into her hands sneezing and farting into the pots well of course shes old she cant help it a good job I found that rotten old smelly dishcloth that got lost behind the dresser I knew there was something and opened the area window to let out the smell bringing in his friends to entertain them like the night he walked home with a dog if you please that might have been mad especially Simon Dedalus son his father such a criticiser with his glasses up with his tall hat on him at the cricket match and a great big hole in his sock one thing laughing at the other and his son that got all those prizes for whatever he won them in the intermediate imagine climbing over the railings if anybody saw him that knew us I wonder he didnt tear a big hole in his grand funeral trousers as if the one nature gave wasnt enough for anybody hawking him down into the dirty old kitchen now is he right in his head I ask pity it wasnt washing day my old pair of drawers might have been hanging up too on the line on exhibition for all he'd ever care with the ironmould mark the stupid old bundle burned on them he might think was something else and she never even rendered down the fat I told her and now shes going such as she was on account of her paralysed husband getting worse there's always something wrong with them disease or they have to go under an operation or if its not that its drink and he beats her I'll have to hunt around again for someone every day I get up there's some new thing on sweet God sweet God well when I'm stretched out dead in my grave I suppose 111 have some peace I want to get up a minute if I'm let wait O Jesus wait yes that thing has come on me yes now wouldnt that afflict you of course all the poking and rooting and ploughing he had up in me now what am I to do Friday Saturday Sunday wouldnt that pester the soul out of a body unless he likes it some men do God knows there's always something wrong with us 5 days every 3 or 4 weeks usual monthly auction isnt it simply sickening that night it came on me like that the one and only time we were in a box that Michael Gunn gave him to see Mrs Kendal and her husband at the Gaiety something he did about insurance for him in Drimmies I was fit to be tied though I wouldnt give in with that gentleman of fashion staring down at me with his glasses and him the other side of me talking about Spinoza and his soul thats dead I suppose millions of years ago I smiled the best I could all in a swamp leaning forward as if I was interested having to sit it out then to the last tag I wont forget that wife of Scarli in a hurry supposed to be a fast play about adultery that idiot in the gallery hissing the woman adulteress he shouted I suppose he went and had a woman in the next lane running round all the back ways after to make up for it I wish he had what I had then he'd boo I bet the cat itself is better off than us have we too much blood up in us or what O patience above its pouring out of me like the sea anyhow he didnt make me pregnant as big as he is I dont want to ruin the clean sheets I just put on I suppose the clean linen I wore brought it on too damn it damn it and they always want to see a stain on the bed to know youre a virgin for them all thats troubling them theyre such fools too you could be a widow or divorced 40 times over a daub of red ink would do or blackberry juice no thats too purply O Jamesy let me up out of this pooh sweets of sin whoever suggested that business for women what between clothes and cooking and children this damned old bed too jingling like the dickens I suppose they could hear us away over the other side of the park till I suggested to put the quilt on the floor with the pillow under my bottom I wonder is it nicer in the day I think it is easy I think I'll cut all this hair off me there scalding me I might look like a young girl wouldnt he get the great suckin the next time he turned up my clothes on me I'd give anything to see his face wheres the chamber gone easy Ive a holy horror of its breaking under me after that old commode I wonder was I too heavy sitting on his knee I made him sit on the easychair purposely when I took off only my blouse and skirt first in the other room he was so busy where he oughtnt to be he never felt me I hope my breath was sweet after those kissing comfits easy God I remember one time I could scout it out straight whistling like a man almost easy O Lord how noisy I hope theyre bubbles on it for a wad of money from some fellow 111 have to perfume it in the morning dont forget I bet he never saw a better pair of thighs than that look how white they are the smoothest place is right there between this bit here how soft like a peach easy God I wouldnt mind being a man and get up on a lovely woman O Lord what a row youre making like the jersey lily easy easy O how the waters come down at Lahore who knows is there anything the matter with my insides or have I something growing in me getting that thing like that every week when was it last I Whit Monday yes its only about 3 weeks I ought to go to the doctor only it would be like before I married him when I had that white thing coming from me and could you pass it easily pass what I thought he was talking about the rock of Gibraltar the way he put it thats a very nice invention too by the way only I like letting myself down after in the hole as far as I can squeeze and pull the chain then to flush it nice cool pins and needles still there's something in it I suppose I always used to know by Millys when she was a child whether she had worms or not still all the same paying him for that how much is that doctor one guinea please and asking me had I frequent omissions where do those old fellows get all the words they have omissions with his shortsighted eyes on me cocked sideways I wouldnt trust him too far to give me chloroform or God knows what else still I liked him when he sat down to write the thing out frowning so severe his nose intelligent like that you be damned you lying strap O anything no matter who except an idiot he was clever enough to spot that of course that was all thinking of him and his mad crazy letters my Precious one everything connected with your glorious Body everything underlined that comes from it is a thing of beauty and of joy for ever something he got out of some nonsensical book that he had me always at myself 4 and 5 times a day sometimes and I said I hadnt are you sure O yes I said I am quite sure in a way that shut him up I knew what was coming next only natural weakness it was he excited me I dont know how the first night ever we met when I was living in Rehoboth terrace we stood staring at one another for about lo minutes as if we met somewhere I suppose on account of my being jewess looking after my mother he used to amuse me the things he said with the half sloothering smile on him and all the Doyles said he was going to stand for a member of Parliament O wasnt I the born fool to believe all his blather about home rule and the land league sending me that long strool of a song out of the Huguenots to sing in French to be more classy O beau pays de la Touraine that I never even sang once explaining and rigmaroling about religion and persecution he wont let you enjoy anything naturally then might he as a great favour the very 1st opportunity he got a chance in Brighton square running into my bedroom pretending the ink got on his hands to wash it off with the Albion milk and sulphur soap I used to use and the gelatine still round it O I laughed myself sick at him that day I better not make an alnight sitting on this affair they ought to make chambers a natural size so that a woman could sit on it properly he kneels down to do it I suppose there isnt in all creation another man with the habits he has look at the way he's sleeping at the foot of the bed how can he without a hard bolster its well he doesnt kick or he might knock out all my teeth breathing with his hand on his nose like that Indian god he took me to show one wet Sunday in the museum in Kildare street all yellow in a pinafore lying on his side on his hand with his ten toes sticking out that he said was a bigger religion than the jews and Our Lords both put together all over Asia imitating him as he's always imitating everybody I suppose he used to sleep at the foot of the bed too with his big square feet up in his wifes mouth damn this stinking thing anyway wheres this those napkins are ah yes I know I hope the old press doesnt creak ah I knew it would he's sleeping hard had a good time somewhere still she must have given him great value for his money of course he has to pay for it from her O this nuisance of a thing I hope theyll have something better for us in the other world tying ourselves up God help us thats all right for tonight now the lumpy old jingly bed always reminds me of old Cohen I suppose he scratched himself in it often enough and he thinks father bought it from Lord Napier that I used to admire when I was a little girl because I told him easy piano O I like my bed God here we are as bad as ever after 16 years how many houses were we in at all Raymond terrace and Ontario terrace and Lombard street and Holles street and he goes about whistling every time were on the run again his huguenots or the frogs march pretending to help the men with our 4 sticks of furniture and then the City Arms hotel worse and worse says Warden Daly that charming place on the landing always somebody inside praying then leaving all their stinks after them always know who was in there last every time were just getting on right something happens or he puts his big foot in it Thoms and Helys and Mr Cuffes and Drimmies either he's going to be run into prison over his old lottery tickets that was to be all our salvations or he goes and gives impudence well have him coming home with the sack soon out of the Freeman too like the rest on account of those Sinner Fein or the freemasons then well see if the little man he showed me dribbling along in the wet all by himself round by Coadys lane will give him much consolation that he says is so capable and sincerely Irish he is indeed judging by the sincerity of the trousers I saw on him wait there's Georges church bells wait 3 quarters the hour l wait 2 oclock well thats a nice hour of the night for him to be coming home at to anybody climbing down into the area if anybody saw him I'll knock him off that little habit tomorrow first I'll look at his shirt to see or I'll see if he has that French letter still in his pocketbook I suppose he thinks I dont know deceitful men all their 20 pockets arent enough for their lies then why should we tell them even if its the truth they dont believe you then tucked up in bed like those babies in the Aristocrats Masterpiece he brought me another time as if we hadnt enough of that in real life without some old Aristocrat or whatever his name is disgusting you more with those rotten pictures children with two heads and no legs thats the kind of villainy theyre always dreaming about with not another thing in their empty heads they ought to get slow poison the half of them then tea and toast for him buttered on both sides and newlaid eggs I suppose I'm nothing any more when I wouldnt let him lick me in Holles street one night man man tyrant as ever for the one thing he slept on the floor half the night naked the way the jews used when somebody dies belonged to them and wouldnt eat any breakfast or speak a word wanting to be petted so I thought I stood out enough for one time and let him he does it all wrong too thinking only of his own pleasure his tongue is too flat or I dont know what he forgets that wethen I dont I'll make him do it again if he doesnt mind himself and lock him down to sleep in the coalcellar with the blackbeetles I wonder was it her Josie off her head with my castoffs he's such a born liar too no he'd never have the courage with a married woman thats why he wants me and down I tried to wink at him first no use of course and thats the way his money goes this is the fruits of Mr Paddy Dignam yes they were all in great style at the grand funeral in the paper Boylan brought in if they saw a real officers funeral thatd be something reversed arms muffled drums the poor horse walking behind in black L Boom and Tom Kernan that drunken little barrelly man that bit his tongue off falling down the mens W C drunk in some place or other and Martin Cunningham and the two Dedaluses and Fanny MCoys husband white head of cabbage skinny thing with a turn in her eye trying to sing my songs shed want to be born all over again and her old green dress with the lowneck as she cant attract them any other way like dabbling on a rainy day I see it all now plainly and they call that friendship killing and then burying one another and they all with their wives and families at home more especially Jack Power keeping that barmaid he does of course his wife is always sick or going to be sick or just getting better of it and he's a goodlooking man still though he's getting a bit grey over the ears theyre a nice lot all of them well theyre not going to get my husband again into their clutches if I can help it making fun of him then behind his back I know well when he goes on with his idiotics because he has sense enough not to squander every penny piece he earns down their gullets and looks after his wife and family goodfornothings poor Paddy Dignam all the same I'm sorry in a way for him what are his wife and 5 children going to do unless he was insured comical little teetotum always stuck up in some pub corner and her or her son waiting Bill Bailey wont you please come home her widows weeds wont improve her appearance theyre awfully becoming though if youre goodlooking what men wasnt he yes he was at the Glencree dinner and Ben Dollard base barreltone the night he borrowed the swallowtail to sing out of in Holles street squeezed and squashed into them and grinning all over his big Dolly face like a wellwhipped childs botty didnt he look a balmy ballocks sure enough that must have been a spectacle on the stage imagine paying 5/- in the preserved seats for that to see him trotting off in his trowlers and Simon Dedalus too he was always turning up half screwed singing the second verse first the old love is the new was one of his so sweetly sang the maiden on the hawthorn bough he was always on for flirtyfying too when I sang Maritana with him at Freddy Mayers private opera he had a delicious glorious voice Phoebe dearest goodbye sweetheart sweetheart he always sang it not like Bartell Darcy sweet tart goodbye of course he had the gift of the voice so there was no art in it all over you like a warm showerbath O Maritana wildwood flower we sang splendidly though it was a bit too high for my register even transposed and he was married at the time to May Goulding but then he'd say or do something to knock the good out of it he's a widower now I wonder what sort is his son he says he's an author and going to be a university professor of Italian and I'm to take lessons what is he driving at now showing him my photo its not good of me I ought to have got it taken in drapery that never looks out of fashion still I look young in it I wonder he didnt make him a present of it altogether and me too after all why not I saw him driving down to the Kingsbridge station with his father and mother I was in mourning thats 11 years ago now yes he'd be 11 though what was the good in going into mourning for what was neither one thing nor the other the first cry was enough for me I heard the deathwatch too ticking in the wall of course he insisted he'd go into mourning for the cat I suppose he's a man now by this time he was an innocent boy then and a darling little fellow in his lord Fauntleroy suit and curly hair like a prince on the stage when I saw him at Mat Dillons he liked me too I remember they all do wait by God yes wait yes hold on he was on the cards this morning when I laid out the deck union with a young stranger neither dark nor fair you met before I thought it meant him but he's no chicken nor a stranger either besides my face was turned the other way what was the 7th card after that the 10 of spades for a journey by land then there was a letter on its way and scandals too the 3 queens and the 8 of diamonds for a rise in society yes wait it all came out and 2 red 8s for new garments look at that and didnt I dream something too yes there was something about poetry in it I hope he hasnt long greasy hair hanging into his eyes or standing up like a red Indian what do they go about like that for only getting themselves and their poetry laughed at I always liked poetry when I was a girl first I thought he was a poet like lord Byron and not an ounce of it in his composition I thought he was quite different I wonder is he too young he's about wait 88 I was married 88 Milly is 15 yesterday 89 what age was he then at Dillons 5 or 6 about 88 I suppose he's 20 or more I'm not too old for him if he's 23 or 24 I hope he's not that stuckup university student sort no otherwise he wouldnt go sitting down in the old kitchen with him taking Eppss cocoa and talking of course he pretended to understand it all probably he told him he was out of Trinity college he's very young to be a professor I hope he's not a professor like Goodwin was he was a potent professor of John Jameson they all write about some woman in their poetry well I suppose he wont find many like me where softly sighs of love the light guitar where poetry is in the air the blue sea and the moon shining so beautifully coming back on the nightboat from Tarifa the lighthouse at Europa point the guitar that fellow played was so expressive will I ever go back there again all new faces two glancing eyes a lattice hid I'll sing that for him theyre my eyes if he's anything of a poet two eyes as darkly bright as loves own star arent those beautiful words as loves young star itll be a change the Lord knows to have an intelligent person to talk to about yourself not always listening to him and Billy Prescotts ad and Keyess ad and Tom the Devils ad then if anything goes wrong in their business we have to suffer I'm sure he's very distinguished I'd like to meet a man like that God not those other ruck besides he's young those fine young men I could see down in Margate strand bathingplace from the side of the rock standing up in the sun naked like a God or something and then plunging into the sea with them why arent all men like that there'd be some consolation for a woman like that lovely little statue he bought I could look at him all day long curly head and his shoulders his finger up for you to listen there's real beauty and white he looks with his boyish face I would too in 1/2 a minute even if some of it went down what its only like gruel or the dew there's no danger besides he'd be so clean compared with those pigs of men I suppose never dream of washing it from I years end to the other the most of them only thats what gives the women the moustaches I'm sure itll be grand if I can only get in with a handsome young poet at my age I'll throw them the 1st thing in the morning till I see if the wishcard comes out or I'll try pairing the lady herself and see if he comes out I'll read and study all I can find or learn a bit off by heart if I knew who he likes so he wont think me stupid if he thinks all women are the same and I can teach him the other part I'll make him feel all over him till he half faints under me then hell write about me lover and mistress publicly too with our 2 photographs in all the papers when he becomes famous O but then what am I going to do about him though no thats no way for him has he no manners nor no refinement nor no nothing in his nature slapping us behind like that on my bottom because I didnt call him Hugh the ignoramus that doesnt know poetry from a cabbage thats what you get for not keeping them in their proper place pulling off his shoes and trousers there on the chair before me so barefaced without even asking permission and standing out that vulgar way in the half of a shirt they wear to be admired like a priest or a butcher or those old hypocrites in the time of Julius Caesar of course he's right enough in his way to pass the time as a joke sure you might as well be in bed with what with a lion God I'm sure he'd have something better to say for himself an old Lion would O well I suppose its because they were so plump and tempting in my short petticoat he couldn't resist they excite myself sometimes its well for men all the amount of pleasure they get off a womans body were so round and white for them always I wished I was one myself for a change just to try with that thing they have swelling up on you so hard and at the same time so soft when you touch it my uncle John has a thing long I heard those cornerboys saying passing the comer of Marrowbone lane my aunt Mary has a thing hairy because it was dark and they knew a girl was passing it didnt make me blush why should it either its only nature and turns out to be you put the handle in a sweepingbrush men again all over they can pick and choose what they please a married woman or a fast widow or a girl for their different tastes like those houses round behind Irish street no but were to be always chained up theyre not going to be chaining me up no damn fear once I start I tell you for their stupid husbands jealousy why cant we all remain friends over it instead of quarrelling her husband found it out what they did together well naturally and if he did can he undo it he's coronado anyway whatever he does and then he going to the other mad extreme about the wife in Fair Tyrants of course the man never even casts a 2nd thought on the husband or wife either its the woman he wants and he gets her what else were we given all those desires for I'd like to know I cant help it if I'm young still can I its a wonder I'm not an old shrivelled hag before my time living with him so cold never embracing me except sometimes when he's asleep the wrong end of me not knowing I suppose who he has any man thatd kiss a womans bottom I'd throw my hat at him after that he'd kiss anything unnatural where we havent I atom of any kind of expression in us all of us the same 2 lumps of lard before ever I'd do that to a man pfooh the dirty brutes the mere thought is enough I kiss the feet of you senorita there's some sense in that didnt he kiss our halldoor yes he did what a madman nobody understands his cracked ideas but me still of course a woman wants to be embraced 20 times a day almost to make her look young no matter by who so long as to be in love or loved by somebody if the fellow you want isnt there sometimes by the Lord God I was thinking would I go around by the quays there some dark evening where nobodyd know me and pick up a sailor off the sea thatd be hot on for it and not care a pin whose I was only do it off up in a gate somewhere or one of those wildlooking gipsies in Rathfarnham had their camp pitched near the Bloomfield laundry to try and steal our things if they could I only sent mine there a few times for the name model laundry sending me back over and over some old ones odd stockings that blackguardlooking fellow with the fine eyes peeling a switch attack me in the dark and ride me up against the wall without a word or a murderer anybody what they do themselves the fine gentlemen in their silk hats that K C lives up somewhere this way coming out of Hardwicke lane the night he gave us the fish supper on account of winning over the boxing match of course it was for me he gave it I knew him by his gaiters and the walk and when I turned round a minute after just to see there was a woman after coming out of it too some filthy prostitute then he goes home to his wife after that only I suppose the half of those sailors are rotten again with disease O move over your big carcass out of that for the love of Mike listen to him the winds that waft my sighs to thee so well he may sleep and sigh the great Suggester Don Poldo de la Flora if he knew how he came out on the cards this morning he'd have something to sigh for a dark man in some perplexity between 2 7s too in prison for Lord knows what he does that I dont know and I'm to be slooching around down in the kitchen to get his lordship his breakfast while he's rolled up like a mummy will I indeed did you ever see me running I'd just like to see myself at it show them attention and they treat you like dirt I dont care what anybody says itd be much better for the world to be governed by the women in it you wouldnt see women going and killing one another and slaughtering when do you ever see women rolling around drunk like they do or gambling every penny they have and losing it on horses yes because a woman whatever she does she knows where to stop sure they wouldnt be in the world at all only for us they dont know what it is to be a woman and a mother how could they where would they all of them be if they hadnt all a mother to look after them what I never had thats why I suppose he's running wild now out at night away from his books and studies and not living at home on account of the usual rowy house I suppose well its a poor case that those that have a fine son like that theyre not satisfied and I none was he not able to make one it wasnt my fault we came together when I was watching the two dogs up in her behind in the middle of the naked street that disheartened me altogether I suppose I oughtnt to have buried him in that little woolly jacket I knitted crying as I was but give it to some poor child but I knew well I'd never have another our 1st death too it was we were never the same since O I'm not going to think myself into the glooms about that any more I wonder why he wouldnt stay the night I felt all the time it was somebody strange he brought in instead of roving around the city meeting God knows who and Pisimbo and Mrs Opisso in Governor street O what a name I'd go and drown myself in the first river if I had a name like her O my and all the bits of streets Paradise ramp and Bedlam ramp and Rodgers ramp and Crutchetts ramp and the devils gap steps well small blame to me if I am a harumscarum I know I am a bit I declare to God I dont feel a day older than then I wonder could I get my tongue round any of the Spanish como esta usted muy bien gracias y usted see I havent forgotten it all I thought I had only for the grammar a noun is the name of any person place or thing pity I never tried to read that novel cantankerous Mrs Rubio lent me by Valera with the questions in it all upside down the two ways I always knew wed go away in the end I can tell him the Spanish and he tell me the Italian then hell see I'm not so ignorant what a pity he didnt stay I'm sure the poor fellow was dead tired and wanted a good sleep badly I could have brought him in his breakfast in bed with a bit of toast so long as I didnt do it on the knife for bad luck or if the woman was going her rounds with the watercress and something nice and tasty there are a few olives in the kitchen he might like I never could bear the look of them in Abrines I could do the criada the room looks all right since I changed it the other way you see something was telling me all the time I'd have to introduce myself not knowing me from Adam very funny wouldnt it I'm his wife or pretend we were in Spain with him half awake without a Gods notion where he is dos huevos estrellados senor Lord the cracked things come into my head sometimes itd be great fun supposing he stayed with us why not there's the room upstairs empty and Millys bed in the back room he could do his writing and studies at the table in there for all the scribbling he does at it and if he wants to read in bed in the morning like me as he's making the breakfast for I he can make it for 2 I'm sure I'm not going to take in lodgers off the street for him if he takes a gesabo of a house like this I'd love to have a long talk with an intelligent welleducated person I'd have to get a nice pair of red slippers like those Turks with the fez used to sell or yellow and a nice semitransparent morning gown that I badly want or a peachblossom dressing jacket like the one long ago in Walpoles only 8/6 or 18/6 I'll just give him one more chance I'll get up early in the morning I'm sick of Cohens old bed in any case I might go over to the markets to see all the vegetables and cabbages and tomatoes and carrots and all kinds of splendid fruits all coming in lovely and fresh who knows whod be the 1st man I'd meet theyre out looking for it in the morning Mamy Dillon used to say they are and the night too that was her massgoing I'd love a big juicy pear now to melt in your mouth like when I used to be in the longing way then I'll throw him up his eggs and tea in the moustachecup she gave him to make his mouth bigger I suppose he'd like my nice cream too I know what I'll do I'll go about rather gay not too much singing a bit now and then mi fa pieta Masetto then I'll start dressing myself to go out presto non son piu forte I'll put on my best shift and make him do it out in front of me serve him right its all his own fault if I am an adulteress as the thing in the gallery said O much about it if thats all the harm ever we did in this vale of tears God knows its not much doesnt everybody only they hide it I suppose thats what a woman is supposed to be there for or He wouldnt have made us the way He did so attractive to men then if he wants to kiss my bottom I'll drag open my drawers and bulge it right out in his face as large as life he can stick his tongue 7 miles up my hole as he's there my brown part then I'll tell him I want LI or perhaps 30/- I'll tell him I want to buy underclothes then if he gives me that well he wont be too bad I dont want to soak it all out of him like other women do I could often have written out a fine cheque for myself and friendly over it O but I was forgetting this bloody pest of a thing pfooh you wouldnt know which to laugh or cry were such a mixture of plum and apple no I'll have to wear the old things so much the better itll be more pointed hell never know whether he did it or not there thats good enough for you any old thing at all then I'll wipe him off me just like a business his omission then I'll go out I'll have him eying up at the ceiling where is she gone now make him want me thats the only way a quarter after what an unearthly hour I suppose theyre just getting up in China now combing out their pigtails for the day well soon have the nuns ringing the angelus theyve nobody coming in to spoil their sleep except an odd priest or two for his night office or the alarmclock next door at cockshout clattering the brains out of itself let me see if I can doze off 1 2 3 4 5 what kind of flowers are those they invented like the stars the wallpaper in Lombard street was much nicer the apron he gave me was like that something only I only wore it twice better lower this lamp and try again so as I can get up early I'll go to Lambes there beside Findlaters and get them to send us some flowers to put about the place in case he brings him home tomorrow today I mean no no Fridays an unlucky day first I want to do the place up someway the dust grows in it I think while I'm asleep then we can have music and cigarettes I can accompany him first I must clean the keys of the piano with milk whatll I wear shall I wear a white rose or those fairy cakes in Liptons I love the smell of a rich big shop at 7 1/2d a lb or the other ones with the cherries in them and the pinky sugar I I'd a couple of lbs of those a nice plant for the middle of the table I'd get that cheaper in wait wheres this I saw them not long ago I love flowers I'd love to have the whole place swimming in roses God of heaven there's nothing like nature the wild mountains then the sea and the waves rushing then the beautiful country with the fields of oats and wheat and all kinds of things and all the fine cattle going about that would do your heart good to see rivers and lakes and flowers all sorts of shapes and smells and colours springing up even out of the ditches primroses and violets nature it is as for them saying there's no God I wouldnt give a snap of my two fingers for all their learning why dont they go and create something I often asked him atheists or whatever they call themselves go and wash the cobbles off themselves first then they go howling for the priest and they dying and why why because theyre afraid of hell on account of their bad conscience ah yes I know them well who was the first person in the universe before there was anybody that made it all who ah that they dont know neither do I so there you are they might as well try to stop the sun from rising tomorrow the sun shines for you he said the day we were lying among the rhododendrons on Howth head in the grey tweed suit and his straw hat the day I got him to propose to me yes first I gave him the bit of seedcake out of my mouth and it was leapyear like now yes 16 years ago my God after that long kiss I near lost my breath yes he said I was a flower of the mountain yes so we are flowers all a womans body yes that was one true thing he said in his life and the sun shines for you today yes that was why I liked him because I saw he understood or felt what a woman is and I knew I could always get round him and I gave him all the pleasure I could leading him on till he asked me to say yes and I wouldnt answer first only looked out over the sea and the sky I was thinking of so many things he didnt know of Mulvey and Mr Stanhope and Hester and father and old captain Groves and the sailors playing all birds fly and I say stoop and washing up dishes they called it on the pier and the sentry in front of the governors house with the thing round his white helmet poor devil half roasted and the Spanish girls laughing in their shawls and their tall combs and the auctions in the morning the Greeks and the jews and the Arabs and the devil knows who else from all the ends of Europe and Duke street and the fowl market all clucking outside Larby Sharons and the poor donkeys slipping half asleep and the vague fellows in the cloaks asleep in the shade on the steps and the big wheels of the carts of the bulls and the old castle thousands of years old yes and those handsome Moors all in white and turbans like kings asking you to sit down in their little bit of a shop and Ronda with the old windows of the posadas 2 glancing eyes a lattice hid for her lover to kiss the iron and the wineshops half open at night and the castanets and the night we missed the boat at Algeciras the watchman going about serene with his lamp and O that awful deepdown torrent O and the sea the sea crimson sometimes like fire and the glorious sunsets and the figtrees in the Alameda gardens yes and all the queer little streets and the pink and blue and yellow houses and the rosegardens and the jessamine and geraniums and cactuses and Gibraltar as a girl where I was a Flower of the mountain yes when I put the rose in my hair like the Andalusian girls used or shall I wear a red yes and how he kissed me under the Moorish wall I thought well as well him as another and then I asked him with my eyes to ask again yes and then he asked me would I yes to say yes my mountain flower and first I put my arms around him yes and drew him down to me so he could feel my breasts all perfume yes and"
